@@ -38,10 +38,10 @@ class GP(FunctionReduce):
         >>>
         >>> gp = GP(y, mean, cov)
         >>> print('Before: %.4f' % gp.feed().value())
-        Before: -164.0064
+        Before: -49.4450
         >>> gp.feed().maximize(verbose=False)
         >>> print('After: %.4f' % gp.feed().value())
-        After: -163.4192
+        After: -49.2888
     """
 
     def __init__(self, y, mean, cov):
@@ -70,7 +70,8 @@ class GP(FunctionReduce):
         Kiym = solve(cov, ym)
 
         (s, logdet) = slogdet(cov)
-        assert s == 1.
+        if not s == 1.0:
+            raise RuntimeError("This determinant should not be negative.")
 
         n = len(self._y)
         return -(logdet + ym.dot(Kiym) + n * log(2 * pi)) / 2
