@@ -1,7 +1,8 @@
 from __future__ import division
 
-from numpy import clip, dot, exp
-from numpy_sugar import is_all_finite
+from numpy import clip, exp, log
+from numpy_sugar import epsilon, is_all_finite
+
 from optimix import Function, Scalar, maximize_scalar
 
 from .core import LMMCore
@@ -118,7 +119,9 @@ class LMM(LMMCore, Function):
 
     @delta.setter
     def delta(self, delta):
+        delta = clip(delta, epsilon.tiny, 1 - epsilon.tiny)
         self._delta = delta
+        self.variables().set(dict(logistic=log(delta / (1 - delta))))
 
     def copy(self):
         # pylint: disable=W0212
@@ -159,7 +162,7 @@ class LMM(LMMCore, Function):
         return self.scale * self.delta
 
     def learn(self, verbose=True):
-        maximize_scalar(self, verbose=verbose)
+        maximize_scalar(self, 'LMM', verbose=verbose)
         self.update()
         self.delta = self._get_delta()
 
